%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%								 	%			
% Newton's Correction Method - We receive an Euler approximation	%
% (alpha,beta,delta), and try to correct it witha sequenc of		%
% Newton steps towards the homotopy path				%
%									%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function u= correct(alpha,beta,delta)

global HOME_EPSILON;

v=[alpha,beta];

Hpv=hprime(v);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Hpv is the Jacobian we will use in newon's method			%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Hpv=Hpv.matrix;


Homv=homotopy(v,delta);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Newton's Step								%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LU factorization to compute the inverse matrix			%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


[L U]=lu(Hpv);

w=v-(U\(L\Homv'))';

Homw=homotopy(w,delta);

diff=sqrt(Homw(1)^2+Homw(2)^2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%		
% If Newtons step is correcting our approximation i.e.making the 	%
% homotopy evaluate closer to zero, then we continue to make Newton's 	%
% steps.If, however, Newton's method is not returning better 		%
% approximations i.e.not converging to the homotopic path, we reduce 	%
% our step size and make a new Euler's prediction step			%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

test=0;

while(diff>HOME_EPSILON)
	test=1;
	v=w;
	Homv=Homw;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% LU factorization to compute the inverse matrix			%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	[L U]=lu(Hpv);
	w=v-(U\(L\Homv'))';

	Homw=homotopy(w,delta);
	diff=sqrt(Homw(1)^2+Homw(2)^2);
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% If newton's method isn't converging to a zero, then we need to make a	% 	 
% smaller step with Eulers method. By sending the false flag, this is 	%
% tested and taken care of in main. Otherwise we have converged to a	%
% point on our path.							%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


if(test==0)
u=struct('question',false,'vector',[alpha,beta,delta]); 
else
u=struct('question',true,'vector',[v(1),v(2),delta]);
end

return


