%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%	
% Homotopy Evaluation Method - Evaluates the value of the 	%
% F(v) - (1 - delta)F(v0) at a given values of v and delta	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function H= homotopy(v,delta)

global ALPHA0;
global XP0;
global BETA0;
global YP0;
global P;
global OPTIONS;
global SOLVER;
global FUNC;

alpha=v(1);
beta=v(2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% The solver is a global parameter in the param.m file.         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

solution=feval(SOLVER,FUNC,[0,P],[alpha,beta],OPTIONS);

xP= solution.y(1,end);
yP= solution.y(2,end);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% We have the right hand part computed once in main and		%
% stored globally to reduce the cost of this function.          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


H1=alpha-xP-(1-delta)*(ALPHA0-XP0);
H2=beta-yP-(1-delta)*(BETA0-YP0);
H=[H1;H2]';
	
