%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% hprime computes the derivative with respect to arc length	%
% in terms of the matrix A, and alphadot,betadot,deltadot 	%
% at an initial condition vector				%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function S=hprime(v)

global P;
global FAZ;
global FBZ;
global OPTIONS;
global SOLVER;
global FUNC;

alpha=v(1);
beta=v(2);

a = 0;
b = P;
xa = alpha;
ya = beta;
h = .01;
M = ceil((b - a)/h);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Here we compute the necessary values for a second order	%
% forward differencing scheme, note that the solver is a global %
% parameter in the param.m file.				%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


soln = feval(SOLVER,FUNC,[a, b],[ xa, ya],OPTIONS);
solnaph = feval(SOLVER,FUNC,[a, b],[ xa + h, ya],OPTIONS);
solnap2h = feval(SOLVER,FUNC,[ a, b],[ xa + 2*h, ya],OPTIONS);
solnbph = feval(SOLVER,FUNC, [a, b],[ xa, ya + h],OPTIONS);
solnbp2h = feval(SOLVER,FUNC,[ a, b],[ xa, ya + 2*h],OPTIONS);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Here we compute the partial derivatives for 			%
% partial(F(v)/partial v) evaluated at time t=P.		%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


pxal=(-3*soln.y(1,end) + 4*solnaph.y(1,end) - solnap2h.y(1,end))/(2*h);
pyal=(-3*soln.y(2,end) + 4*solnaph.y(2,end) - solnap2h.y(2,end))/(2*h);

pxbt=(-3*soln.y(1,end) + 4*solnbph.y(1,end) - solnbp2h.y(1,end))/(2*h);
pybt=(-3*soln.y(2,end) + 4*solnbph.y(2,end) - solnbp2h.y(2,end))/(2*h);




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fa and fb are just F(v_0) we have them stored globally to 	%
% reduce the cost of this function.				%	
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fa=FAZ;
fb=FBZ;

x1 = 1 - pxal;
x2 = -pyal;
y1 = -pxbt;
y2 = 1 - pybt;

A=[x1 y1;x2 y2];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%		
%Here we solve for alphadot, betadot, and deltadot using Cramer's rule	%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

z1 = fa;
z2 = fb;
d = x1*y2 - x2*y1;
deltadot = 1/sqrt((z2*y1 - z1*y1)^2/d^2 + (z1*x2 - z2*x1)^2/d^2 + 1);
alphadot = deltadot*(z2*y1 - z1*y2)/d;
betadot = deltadot*(z1*x2 - z2*x1)/d;

S=struct('matrix',A,'vector',[alphadot,betadot,deltadot]);

return;
