%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Global variables						%
%								%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global ALPHA0;
global XP0;
global BETA0;
global DELTA0;
global YP0;
global HOME_EPSILON;
global FAZ;
global FBZ;
global P;
global OPTIONS;
global SOLVER;
global FUNC;
global X_ABS_TOL;
global Y_ABS_TOL;
global REL_TOL;
global EPSILON;

DELTA0=0;

params; % Here we read in the global parameters in params.m

epsilon = EPSILON; % since epsilon shouldn't change we didn't want to chance it being global
step = 1/10; %step is the inital guess that you will chose for Euler's stepsize
n = 0; % n can be used for testing the number of iterations but we removed it.

solution0=feval(SOLVER,FUNC,[0,P],[ALPHA0,BETA0],OPTIONS);

figure
plot(solution0.y(1,:),solution0.y(2,:));
title('Initial solution guess');

XP0=solution0.y(1,end);
YP0=solution0.y(2,end);

FAZ=ALPHA0-XP0;
FBZ=BETA0-YP0;


alpha = ALPHA0;
beta = BETA0;
delta = DELTA0;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Begin the Predictor correction method				%
%								%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


while(delta<1)


	u=[alpha,beta,delta];
	Hpu=hprime(u); 	% Solve the linear system for 
			% alphadot, betadot, deltadot
	v=Hpu.vector;
	alphadot=v(1);
	betadot=v(2);
	deltadot=v(3);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% We know deltadot>0 since the homotopy is a continuation method%
% so we adjust accordingly.					%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


	if(deltadot<0)
		alphadot=-alphadot;
		betadot=-betadot;
		deltadot=-deltaot;
	end




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% HERE ARE THE POINTS OBTAINED VIA EULERS APPROXIMATION 	%					
%								%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


	alphaold = alpha;
	betaold = beta;
	deltaold = delta;
	alpha = alphaold + step*alphadot;
	beta = betaold + step*betadot;
	delta = deltaold + step*deltadot;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% HERE WE CORRECT USING NEWTON'S METHOD			 	%					
%								%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

	if(delta<1)
		if(abs(delta-1)<epsilon)break;end;% We are within epsilon of delta=1
		
		q=correct(alpha,beta,delta); % You can print these to see how you are doing.
					     	
		if(q.question==true)% Newton's method found a point on the path
			alpha=q.vector(1);
			beta=q.vector(2);
			delta=q.vector(3);
			step=step*2;
		else  	% Eulers method made too big of a step in delta  
			% for Newton's method to converge
			alpha=alphaold;
			beta=betaold;
			delta=deltaold;
			step=(1/2)*step;
		end
	else % Eulers method sent delta past 1
		alpha=alphaold;
		beta=betaold;
		delta=deltaold;
		step=(1/2)*step;
	end

end % end while loop



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% We have now computed the initial conditions alpha* and beta*	%					
%								%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


options = odeset('RelTol',1e-12,'AbsTol',[1e-16 1e-16]);
fin=ode45(FUNC,[0,P],[alpha beta],options);

figure
plot(fin.y(1,:),fin.y(2,:));
title('final solution');
alpha
beta

fin.y(1,1)- fin.y(1,end)
fin.y(2,1)- fin.y(2,end)

